pub fn mtanh_profile_derivatives(
psi_norm: f64,
params: &ProfileParams,
) -> [f64; 4]Expand description
Re-export profile derivatives for callers expecting this symbol in jacobian.
pub fn mtanh_profile_derivatives(
psi_norm: f64,
params: &ProfileParams,
) -> [f64; 4]Re-export profile derivatives for callers expecting this symbol in jacobian.