pub struct RuntimeKernelJit { /* private fields */ }Expand description
Runtime kernel specialization manager with cache + hot-swap semantics.
Implementations
Sourceimpl RuntimeKernelJit
impl RuntimeKernelJit
pub fn new() -> Self
Sourcepub fn compile_for_regime(
&mut self,
regime: PlasmaRegime,
spec: KernelCompileSpec,
) -> FusionResult<u64>
pub fn compile_for_regime( &mut self, regime: PlasmaRegime, spec: KernelCompileSpec, ) -> FusionResult<u64>
Compile or reuse a kernel for the requested regime and activate it.
Sourcepub fn refresh_for_observation(
&mut self,
observation: &RegimeObservation,
spec: KernelCompileSpec,
) -> FusionResult<(PlasmaRegime, u64)>
pub fn refresh_for_observation( &mut self, observation: &RegimeObservation, spec: KernelCompileSpec, ) -> FusionResult<(PlasmaRegime, u64)>
Detect regime, compile if needed, and activate specialized kernel.
pub fn active_regime(&self) -> Option<PlasmaRegime>
pub fn cache_size(&self) -> usize
pub fn compile_events(&self) -> u64